//***************************************************************************
/*
 * TOra - An Oracle Toolkit for DBA's and developers
 * Copyright (C) 2003 Quest Software, Inc
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation;  only version 2 of
 * the License is valid for this program.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 *      As a special exception, you have permission to link this program
 *      with the Oracle Client libraries and distribute executables, as long
 *      as you follow the requirements of the GNU GPL in regard to all of the
 *      software in the executable aside from Oracle client libraries.
 *
 *      Specifically you are not permitted to link this program with the
 *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
 *      And you are not permitted to distribute binaries compiled against
 *      these libraries without written consent from Quest Software, Inc.
 *      Observe that this does not disallow linking to the Qt Free Edition.
 *
 * All trademarks belong to their respective owners.
 *
 ****************************************************************************/

#ifndef TORESULTPARAM_H
#define TORESULTPARAM_H

#include "toresult.h"

#include <map>

#include <qvbox.h>

class QLineEdit;
class QToolButton;
class toResultView;

/** This widget displays the parameters of a session and lets
 * you edit them.
 */

class toResultParam : public QVBox, public toResult {
  Q_OBJECT

  QString LastItem;
  QString LastValue;
  std::map<QString,QString> NewValues;

  toResultView *Params;
  QLineEdit *Value;
  QToolButton *Toggle;

  void saveChange();
public:
  /** Create the widget.
   * @param parent Parent widget.
   * @param name Name of widget.
   */
  toResultParam(QWidget *parent,const char *name=NULL);

  virtual bool canHandle(toConnection &conn);
private slots:
  void generateFile(void);
  void applySession(void);
  void applySystem(void);
  void applyChanges(void);
  void changeItem(void);
  void changedData(int row,int col,const QString &data);
  void dropChanges(void);
  void done(void);
  void showHidden(bool);
  void showGlobal(bool);
public slots:
  virtual void query(const QString &sql,const toQList &param);
  /** Reimplemented for internal reasons.
   */
  virtual void refresh(void)
  { toResult::refresh(); }
  /** Reimplemented for internal reasons.
   */
  virtual void changeParams(const QString &Param1)
  { toResult::changeParams(Param1); }
  /** Reimplemented For internal reasons.
   */
  virtual void changeParams(const QString &Param1,const QString &Param2)
  { toResult::changeParams(Param1,Param2); }
  /** Reimplemented for internal reasons.
   */
  virtual void changeParams(const QString &Param1,const QString &Param2,const QString &Param3)
  { toResult::changeParams(Param1,Param2,Param3); }
};

#endif
